## $Id: permissions.py 17824 2024-06-27 09:55:33Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import grok
from waeup.kofa.permissions import CCOfficer

class UploadPassportPictures(grok.Permission):
    grok.name('waeup.uploadPassportPictures')

class ClearLibrary(grok.Permission):
    grok.name('waeup.switchLibraryAccess')

class ExportNYSCData(grok.Permission):
    """NYSC Officers don't have the general exportData
    permission and are only allowed to export NYSC data.
    The ExportNYSCData permission is only used to filter the
    respective exporter in the ExportJobContainerJobConfig view.
    """
    grok.name('waeup.exportNYSCData')

class PassportPictureManager(grok.Role):
    grok.name('waeup.PassportPictureManager')
    grok.title(u'Passport Picture Manager')
    grok.permissions('waeup.uploadPassportPictures')

class LibraryClearanceOfficer(grok.Role):
    """Library Clearance Officers can enable library id card slips.
    """
    grok.name('waeup.LibraryClearanceOfficer')
    grok.title(u'Library Clearance Officer')
    grok.permissions('waeup.showStudents',
                     'waeup.viewAcademics',
                     'waeup.switchLibraryAccess')

class NYSCOfficer(grok.Role):
    """NYSC Officers can export NYSC and  data. They can't
    access the Data Center but see student data export buttons in the
    Academic Section.
    """
    grok.name('waeup.NYSCOfficer')
    grok.title(u'NYSC Officer')
    grok.permissions('waeup.showStudents',
                     'waeup.viewAcademics',
                     'waeup.exportNYSCData',)

class CRPUOfficer(CCOfficer):
    """ Permissions of Uniben CRPU members.

    This is basically a copy of the the PortalManager. We exclude some
    permissions by commenting them out.
    """

    grok.name('waeup.CCOfficer')
    grok.title(u'Uniben CRPU Officer')
